@@ -1,3 +1,6 @@
+import math
+from urllib.parse import urlencode
+
 from django.core.cache import caches
 from django.http import Http404, HttpResponse
 from django_filters.rest_framework import DjangoFilterBackend
@@ -143,3 +146,29 @@ class SharePointSearchViewSet(AbstractSharePointViewSet):
             return response
         except ClientRequestException:
             raise Http404
+
+    def list(self, request, *args, **kwargs):
+        def get_link(page):
+            last_dict = request.query_params.copy()
+            if page == 1:
+                last_dict['page'] = str(page)
+                return request.build_absolute_uri('?')
+            elif page > 1:
+                last_dict['page'] = str(page)
+                return request.build_absolute_uri('?') + '?' + urlencode(last_dict)
+
+        response = super().list(request, *args, **kwargs)
+        current_page = int(self.request.query_params.get('page', 1))
+        last_offset = math.ceil(self.total_rows / config.SHAREPOINT_PAGE_SIZE)
+        prev_offset = current_page - 1
+        next_offset = current_page + 1 if current_page < last_offset else 0
+
+        response.data = {
+            "first": request.build_absolute_uri('?'),
+            "last": get_link(last_offset),
+            "previous": get_link(prev_offset),
+            "next:": get_link(next_offset),
+            "total_rows": self.total_rows,
+            "items": response.data,
+        }
+        return response
